@@ -303,6 +303,7 @@ use LWP::UserAgent ();
 use vars qw(@ISA @EXPORT);
 
 my $DEBUG = 0;
+my $bummer = ($^O =~ /MSWin/);
 my %uops = ();
 my @userAgentOps = ();
 
@@ -321,7 +322,10 @@ sub new
 
 	my @okStreams;
 
-	foreach my $p ("$ENV{HOME}/.config/StreamFinder/config", "$ENV{HOME}/.config/StreamFinder/Youtube/config") {
+	my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
+	$homedir ||= $ENV{'LOGDIR'}  if ($ENV{'LOGDIR'});
+	$homedir =~ s#[\/\\]$##;
+	foreach my $p ("${homedir}/.config/StreamFinder/config", "${homedir}/.config/StreamFinder/Youtube/config") {
 		if (open IN, $p) {
 			my ($atr, $val);
 			while (<IN>) {
